This implements the trivial change needed to move back from the hip{Something}_{x, y, z} macros to the natural CUDA syntax of Something.{x, y, z}. This is contained in lines 384-404 in hip_runtime.h. All of the other changes have to do with changing unit tests to use this syntax. The macros are retained for backwards compatibility.

[ROCm/hip commit: cffd0e14eb]
This commit is contained in:
Alex Voicu
2017-11-19 01:54:12 +00:00
förälder 0fd5239b14
incheckning 962bf7bfda
60 ändrade filer med 270 tillägg och 248 borttagningar
@@ -17,8 +17,8 @@ __global__ void tex2DKernel(float* outputData,
int width,
int height)
{
int x = hipBlockIdx_x*hipBlockDim_x + hipThreadIdx_x;
int y = hipBlockIdx_y*hipBlockDim_y + hipThreadIdx_y;
int x = blockIdx.x*blockDim.x + threadIdx.x;
int y = blockIdx.y*blockDim.y + threadIdx.y;
outputData[y*width + x] = tex2D<float>(textureObject, x, y);
}